﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

using Telerik.Windows.Controls;
using Telerik.Windows.Controls.Diagrams;
using Telerik.Windows.Controls.Map;
using Telerik.Windows.Diagrams.Core;

namespace Maps
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{

		private const double DotSize = 10D;

		public MainWindow()
		{
			InitializeComponent();
			Loaded += OnLoaded;
			this.radMap.Provider = new BingMapProvider(MapMode.Road, true, "AnmoOD3Zil3_OvV23xorVummIT1sbTttM9H7L7yMHdQXvuj3-fD2UOZ_EsRoFMDg");
			this.radMap.InitializeCompleted += RadMapOnInitializeCompleted;
		}

		private void RadMapOnInitializeCompleted(object sender, EventArgs eventArgs)
		{
			radMap.Center = new Location(48.654202, 16.281738);
			radMap.ZoomLevel = 5;
		}

		private IShape AddShape(System.Windows.Vector v)
		{
			var s = new RadDiagramShape
			{
				Content = ".",
				Geometry = ShapeFactory.GetShapeGeometry(CommonShapeType.EllipseShape),
				Position = new Point(v.X-DotSize/2, v.Y-DotSize/2),
				Width = DotSize,
				Height = DotSize
			};
			diagram.AddShape(s);
			return s;
		}
		private RadDiagramConnection AddConnection(IShape from ,IShape to, string text = "")
		{
			var con = diagram.AddConnection(from, to) as RadDiagramConnection;
			var label = new TextBlock() { Foreground = Brushes.OrangeRed,Text = text};
			con.TargetCapType = CapType.Arrow1Filled;
			con.Background = Brushes.OrangeRed;
			con.Stroke = Brushes.OrangeRed;
			con.StrokeThickness = 3;
			con.Content = label;
			return con;
		}
		private void OnLoaded(object sender, RoutedEventArgs routedEventArgs)
		{
			// position the diagram surface so that it's covering Europe somewhat
			var root = new Location(63.064251, -23.334961);
			var proot = root.GetPoint(radMap);
			MapLayer.SetLocation(diagram, root);

			// define some geolocations
			var manchester = new Location(53.497632, -2.208252);
			var london = new Location(51.464047, -0.120850);
			var sofia = new Location(42.6957539183824, 23.3327663758679);
			var madrid = new Location(40.342078, -3.680420);
			var copenhagen = new Location(55.675932, 12.595825);

			// get the screen positions
			var plondon = london.GetPoint(radMap);
			var pmanchester = manchester.GetPoint(radMap);
			var psofia = sofia.GetPoint(radMap);
			var pcopenhagen = copenhagen.GetPoint(radMap);
			var pmadrid = madrid.GetPoint(radMap);

			// position the shapes with respect to the diagram surface
			var sofiaShape = this.AddShape(psofia - proot);
			var londonShape = this.AddShape(plondon - proot);
			var copenhagenShape = this.AddShape(pcopenhagen - proot);
			var madridShape = this.AddShape(pmadrid - proot);
			var manchesterShape = this.AddShape(pmanchester - proot);
			this.AddConnection(manchesterShape, londonShape, "Flight SN-5419");
			this.AddConnection(londonShape, madridShape, "Flight ZS-440");
			this.AddConnection(madridShape, sofiaShape, "Flight PL-7888");
			var con = this.AddConnection(sofiaShape, copenhagenShape, "Tentative, to be confirmed");
			con.StrokeDashArray = new DoubleCollection { 2, 2 };
		}


	}

}
